Contributing
============

Contributions
-------------

Please report any bugs, issues or feature requests here:
https://github.com/plone/plone.app.event/issues.

And better yet, help out with documentation and pull-requests!

.. note::

    To accept your pull requests, we need you need to have Plone contributors
    agreement signed and sent-in. For more information, see:
    ` Contributor's Agreement for Plone Explained <http://plone.org/foundation/contributors-agreement/contributors-agreement-explained>`_.


Contributors
------------

Contributors, please add you name here! By doing this, you also state, that you
have signed the `Contributor's Agreement for Plone Explained
<http://plone.org/foundation/contributors-agreement/contributors-agreement-explained>`_.
Download it from `plone.org
<http://plone.org/foundation/contributors-agreement/agreement.pdf/view>`_.
Thanks!

- Johannes Raggam, thet (Main author and PLIP implementation)
- Andreas Jung, zopyx
- David Glick, davisagli
- Érico Andrei, ericof
- Franklin Kingma, kingel
- Gauthier Bastien, gbastien
- Georg Bernhard, gogo
- Giacomo Spettoli, giacomos
- Guido Stevens, gyst
- JeanMichel FRANCOIS, toutpt
- Jens Klein, jensens
- Lennart Regebro, regebro
- Nathan Van Gheem, vangheem
- Philip Bauer, pbauer
- Robert Niederreiter, rnixx
- Rok Garbas, garbas
- Róman Joost, romanofski
- Sean Upton, seanupton
- Simone Orsi, simahawk
- Thomas Desvenain, tdesvenain
- Timo Stollenwerk, timo
- Tom Gross, tomgross
- Vincent Fretin, vincentfretin
- Vitaliy Podoba, piv, vipod
- Wolfgang Thomas, pysailor

Find out who contributed::

    $ git shortlog -s -e

